.. _spkg_sortedcontainers:

sortedcontainers: sorted collections library
================================================

Description
-----------

Sorted collections library, written in pure-Python

License
-------

Apache2

Upstream Contact
----------------

https://pypi.org/project/sortedcontainers



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.4.0

version_requirements.txt::

    sortedcontainers

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install sortedcontainers

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sortedcontainers

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add py3-sortedcontainers

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-sortedcontainers

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install sortedcontainers

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python-sortedcontainers

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install devel/py-sortedcontainers

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/sortedcontainers

.. tab:: OpenBSD:

   install the following packages: devel/py-sortedcontainers

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python-sortedcontainers

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-sortedcontainers


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
